<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://kamleshyadav.com/
 * @since      1.0.0
 *
 * @package    Whatsappchitchat
 * @subpackage Whatsappchitchat/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Whatsappchitchat
 * @subpackage Whatsappchitchat/admin
 * @author     Kamlesh Yadav <support@himanshusofttech.com>
 */
class Whatsappchitchat_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Whatsappchitchat_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Whatsappchitchat_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( 'wp-color-picker');  
		//
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/whatsappchitchat-admin.css', array(), $this->version, 'all' );
	
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() { 

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Whatsappchitchat_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Whatsappchitchat_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		?>
	
		<?php
		
		wp_enqueue_script( 'tinymce_js', includes_url( 'js/tinymce/' ) . 'wp-tinymce.php', array( 'jquery' ), false, true );				
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/whatsappchitchat-admin.js', array( 'jquery','wp-color-picker' ), $this->version,true );		
		wp_enqueue_script( 'whatsappchitchat-admin-tab', plugin_dir_url( __FILE__ ) . 'js/whatsappchitchat-admin-tab.js', array( 'jquery-ui-tabs' ,'wp-color-picker'), $this->version, false );

	} 
	
	public function whatsappchitchat_adminmenu(){
		add_menu_page(       
			'Whatsapp Chit Chat Settings',    
			'Chitchat',              
			'manage_options',           
			'whatsappchitchat_menu',      
			array( $this, 'whatsappchitchat_add_adminmenu'),
			plugin_dir_url( __FILE__ ).'images/whatsapp.png'
		); 
	}
	
	public function whatsappchitchat_add_adminmenu(){
		wp_enqueue_style( 'jquery-ui', plugin_dir_url( __FILE__ ) . 'css/jquery-ui.css', array(), '', 'all' );
		if(isset($_POST['wc_submit'])){
			
		    $wc_show_fpage=$wc_show_page=$wc_show_post=$wc_show_site='';
			
			if(isset($_POST['wc_show_fpage'])){
		        $wc_show_fpage=$_POST['wc_show_fpage'];
		    }
		     if(isset($_POST['wc_show_page'])){
		        $wc_show_page=$_POST['wc_show_page'];
		    }
		     if(isset($_POST['wc_show_post'])){
		        $wc_show_post=$_POST['wc_show_post'];
		    }
		     if(isset($_POST['wc_show_site'])){
		        $wc_show_site=$_POST['wc_show_site'];
		    }
 
			$data=array(
				'wc_onoff' => $_POST['wc_onoff'],
				'wc_mobile_onoff' => $_POST['wc_mobile_onoff'],
				'wc_mobile_no' => $_POST['wc_mobile_no'],
				'wc_chat_id' => $_POST['wc_chat_id'],
				'wc_message' => $_POST['wc_message'],
				'wc_tooltip_message' => $_POST['wc_tooltip_message'],
				'wc_show_fpage' => $wc_show_fpage,
				'wc_show_page' => $wc_show_page,
				'wc_show_post' => $wc_show_post,
				'wc_show_site' => $wc_show_site,
				'wc_bg_color' => $_POST['wc_bg_color'],
				'wc_hvr_color' => $_POST['wc_hvr_color'],
				'wc_bdr_color' => $_POST['wc_bdr_color'],
				'wc_icon_size' => $_POST['wc_icon_size'],
				'wc_icon_position' => $_POST['wc_icon_position'],
				'wc_share_onoff' => $_POST['wc_share_onoff'],
				'wc_button_txt' => $_POST['wc_button_txt'],
				'wc_share_message' => $_POST['wc_share_message'],
				'wc_tooltip_share_message' => $_POST['wc_tooltip_share_message'],
				'wc_bg_sharecolor' => $_POST['wc_bg_sharecolor'],
				'wc_txt_sharecolor' => $_POST['wc_txt_sharecolor'],
				'wc_txthvr_sharecolor' => $_POST['wc_txthvr_sharecolor'],
				'wc_animation' => $_POST['wc_animation'],
				'wc_display_type' => $_POST['wc_display_type'],
			);
			 update_option( 'whatsapp_options', $data );
			 
		}
		require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-admin-display.php';
	}
	
   public function whatsappchitchat_tinymce_button(){
	   if( !current_user_can( 'edit_posts' ) && !current_user_can( 'edit_pages' ) ) {
            return;
          } 
		  
		if ( get_user_option( 'rich_editing' ) !== 'true' ) {
            return;
        }
         
	}
	
	public function whatsappchitchat_tinymce_add_button( $plugin_array ) {
    $plugin_array['Whatsapp_chitchat'] = plugin_dir_url( __FILE__ ) . 'js/whatsappchitchat-admin.js';
	$plugin_array['Whatsapp_share'] = plugin_dir_url( __FILE__ ) . 'js/whatsappchitchat-admin.js';
    return $plugin_array;
    }
	
    public function whatsappchitchat_tinymce_register_button( $buttons ) {
        array_push( $buttons, 'Whatsapp_chitchat'); 
		array_push( $buttons, 'Whatsapp_share'); 
        return $buttons;
    }
	
	public function whatsappchitchat_widget() {
        require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-widget.php';
    }
  
}
