<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://kamleshyadav.com/
 * @since      1.0.0
 *
 * @package    Whatsappchitchat
 * @subpackage Whatsappchitchat/public
 */

/**
 * The public-facing functionality of the plugin. 
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Whatsappchitchat
 * @subpackage Whatsappchitchat/public
 * @author     Kamlesh Yadav <support@himanshusofttech.com>
 */
class Whatsappchitchat_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Whatsappchitchat_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Whatsappchitchat_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/whatsappchitchat-public.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'font-awesome', plugin_dir_url( __FILE__ ) . 'css/font-awesome.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	 public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Whatsappchitchat_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Whatsappchitchat_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/whatsappchitchat-public.js', array( 'jquery' ), $this->version, false );
 
	}
	
 
	public function whatsappchitchat_icon_display($atts,$content = null){
		
		extract( shortcode_atts(
			array(
				'size' => '',
			), $atts )
		);		
						
		$option_values = get_option( 'whatsapp_options' );
		$wc_onoff =$wc_mobile_onoff= $wc_mobile_no =$wc_message=$wc_tooltip_message=$wc_chat_id=$wc_icon_position=$wc_icon_tiny_size='';
		if( $option_values ) {
			$wc_onoff = $option_values['wc_onoff'] ? $option_values['wc_onoff'] : '';
			$wc_mobile_no = isset($option_values['wc_mobile_no']) ? $option_values['wc_mobile_no'] : '';
			$wc_chat_id = isset($option_values['wc_chat_id']) ? $option_values['wc_chat_id'] : '';
			$wc_bg_color = isset($option_values['wc_bg_color']) ? $option_values['wc_bg_color'] : '';
			$wc_hvr_color = isset($option_values['wc_hvr_color']) ? $option_values['wc_hvr_color'] : '';
			$wc_bdr_color = isset($option_values['wc_bdr_color']) ? $option_values['wc_bdr_color'] : '';
			$wc_message = isset($option_values['wc_message']) ? $option_values['wc_message'] : '';
			$wc_tooltip_message = isset($option_values['wc_tooltip_message']) ? $option_values['wc_tooltip_message'] : '';
		}
		$wc_icon_tiny_size = $size;	
		if(empty($wc_message)){
			$wc_message='I Have Doubts!';
		}
		if(empty($wc_tooltip_message)){
			$wc_tooltip_message='How can we help you! just message us.';
		}
		ob_start();	
		if($wc_onoff=='on' && !empty($wc_mobile_no)){ ?> 
				<span class="wc_public_wrapper wc_tinybutton">
					<span id="wc_tooltip">
					 
					<?php 					
					$wcIconUrl = 'https://api.whatsapp.com/send?phone='.$wc_mobile_no.'&text='.$wc_message;
					if(!empty($wc_icon_tiny_size)){ ?>
						<a href="<?php echo esc_url($wcIconUrl); ?>" class="wc_icon_display <?php echo 'wc_'.esc_attr($wc_icon_tiny_size);?>" tooltip="<?php echo esc_attr($wc_tooltip_message);?>" target="_blank" style="background-color:<?php echo esc_attr($wc_bg_color);?>;border-color:<?php echo esc_attr($wc_bg_color);?>;"> 
					<?php }else{ ?>
						<a href="<?php echo esc_url($wcIconUrl); ?>" class="wc_icon_display wc_small" tooltip="<?php echo esc_attr($wc_tooltip_message);?>" target="_blank" style="background-color:<?php echo esc_attr($wc_bg_color);?>;border-color:<?php echo esc_attr($wc_bg_color);?>;">
					<?php } ?> 
					<i class="fa fa-whatsapp" aria-hidden="true"></i></a>
					
					<input type="hidden" id="wc_main_hvr_color" value="<?php echo esc_attr($wc_hvr_color); ?>">
			<input type="hidden" id="wc_main_bdr_color" value="<?php echo esc_attr($wc_bdr_color); ?>">
					</span>
				</span> 
		<?php }else if($wc_onoff=='on' && !empty($wc_chat_id)){ ?>
			<div class="wc_public_wrapper">
			<p id="wc_tooltip">
			<?php 
			$wcChatUrl = 'https://chat.whatsapp.com/invite/'.$wc_chat_id;
			if(!empty($wc_icon_tiny_size)){ ?>
				<a href="<?php echo esc_url($wcChatUrl); ?>" class="wc_icon_display <?php echo 'wc_'.esc_attr($wc_icon_tiny_size);?>" tooltip="<?php echo esc_attr($wc_tooltip_message);?>" target="_blank" style="background-color:<?php echo esc_attr($wc_bg_color);?>;border-color:<?php echo esc_attr($wc_bg_color);?>;">
			<?php }else{ ?>
				<a href="<?php echo esc_url($wcChatUrl); ?>" class="wc_icon_display wc_small" tooltip="<?php echo esc_attr($wc_tooltip_message);?>" target="_blank" style="background-color:<?php echo esc_attr($wc_bg_color);?>;border-color:<?php echo esc_attr($wc_bg_color);?>;">
			<?php } ?> 
			<i class="fa fa-whatsapp" aria-hidden="true"></i></a>
			
			<input type="hidden" id="wc_main_hvr_color" value="<?php echo esc_attr($wc_hvr_color); ?>">
			<input type="hidden" id="wc_main_bdr_color" value="<?php echo esc_attr($wc_bdr_color); ?>">
			</p> 
 
		</div>
		
	<?php 
 
	} ?>
	 
	<?php return ob_get_clean(); 
	}
	
	
	public function whatsappchitchat_on_off(){				
		require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-public-display.php';			
	}
	
	public function whatsappchitchat_show_icon(){
	    $option_values = get_option( 'whatsapp_options' );
        $wc_show_fpage =$wc_show_page=$wc_show_post=$wc_show_site= '';
        if( $option_values ) {
            $wc_show_fpage = isset($option_values['wc_show_fpage']) ? $option_values['wc_show_fpage'] : '';
            $wc_show_page = isset($option_values['wc_show_page']) ? $option_values['wc_show_page'] : '';
            $wc_show_post = isset($option_values['wc_show_post']) ? $option_values['wc_show_post'] : '';
            $wc_show_site = isset($option_values['wc_show_site']) ? $option_values['wc_show_site'] : '';
			
        }
        if($wc_show_fpage==true && $wc_show_fpage='Frontpage'){
			if(is_front_page()  || is_home())	
			{   
				 require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-public-display.php';
			}
        }
        if($wc_show_page==true && $wc_show_page='Pages'){
			if(is_page())	
			{   
				 require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-public-display.php';
			}
        }
        if($wc_show_post==true && $wc_show_post='Posts'){
            global  $post;
	        $posttype = get_post_type($post );
			if(is_single()  || is_archive() || (is_category()) && ( $posttype == 'post'))	
			{   
				 require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-public-display.php';
			}
        }
        if($wc_show_site==true && $wc_show_site='Wholesite'){
            global  $post;
	        $posttype = get_post_type($post );
			if(is_single()  || is_archive() || (is_category()) || ( $posttype == 'post') || is_front_page()  || is_home() || is_page() || is_search() || is_tag())	
			{   
				 require plugin_dir_path(__FILE__).'/partials/whatsappchitchat-public-display.php';
			}
        }
		
	}
	
	public function whatsappchitchat_share_button(){
	
		$option_values = get_option( 'whatsapp_options' );
		$wc_share_onoff =$wc_share_message=$wc_tooltip_share_message=$wc_bg_sharecolor=$wc_txt_sharecolor=$wc_animation=$wc_display_type='';
		if( $option_values ) {
		   $wc_share_onoff = $option_values['wc_share_onoff'] ? $option_values['wc_share_onoff'] : '';
		   $wc_button_txt = $option_values['wc_button_txt'] ? $option_values['wc_button_txt'] : '';
		   $wc_share_message = $option_values['wc_share_message'] ? $option_values['wc_share_message'] : '';
		   $wc_tooltip_share_message = $option_values['wc_tooltip_share_message'] ? $option_values['wc_tooltip_share_message'] : '';
		   $wc_bg_sharecolor = $option_values['wc_bg_sharecolor'] ? $option_values['wc_bg_sharecolor'] : '';
			$wc_txt_sharecolor = $option_values['wc_txt_sharecolor'] ? $option_values['wc_txt_sharecolor'] : '';
			$wc_txthvr_sharecolor = $option_values['wc_txthvr_sharecolor'] ? $option_values['wc_txthvr_sharecolor'] : '';
			$wc_animation = $option_values['wc_animation'] ? $option_values['wc_animation'] : '';
			$wc_display_type = $option_values['wc_display_type'] ? $option_values['wc_display_type'] : '';
		}

		if(empty($wc_share_message)){
			$wc_share_message='I like it. Click on the link';
		}
		if(empty($wc_tooltip_share_message)){
			$wc_tooltip_share_message='Share this to your friends!';
		}
		if(empty($wc_button_txt)){
			$wc_button_txt=' Share Via WhatsApp';
		}

		global $post;
		ob_start();
		if($wc_share_onoff=='on'){	 ?>
			<span class="wc_public_share_wrapper">
			<span id="wc_tooltip">
			<?php	
				$wcShareUrl = 'https://api.whatsapp.com/send?text='.$wc_share_message.'%20'.urlencode(get_the_permalink($post->ID));
				if($wc_display_type=='icon_text'){ ?>
					<a href="<?php echo esc_url($wcShareUrl); ?>" class="wc_share_icon_display wc_icon_text <?php echo 'wc_button_'.esc_attr($wc_animation);?>" tooltip="<?php echo esc_attr($wc_tooltip_share_message);?>" target="_blank" action="share/whatsapp/share" style="background-color:<?php echo esc_attr($wc_bg_sharecolor);?>;color:<?php echo esc_attr($wc_txt_sharecolor);?>;"><i class="fa fa-whatsapp" aria-hidden="true"></i><?php echo esc_html($wc_button_txt);?>
			<?php	}else if($wc_display_type=='only_icon'){ ?>
					<a href="<?php echo esc_url($wcShareUrl); ?>" class="wc_share_icon_display wc_only_icon <?php echo 'wc_button_'.esc_attr($wc_animation);?>" tooltip="<?php echo esc_attr($wc_tooltip_share_message);?>" target="_blank" action="share/whatsapp/share" style="background-color:<?php echo esc_attr($wc_bg_sharecolor);?>;color:<?php echo esc_attr($wc_txt_sharecolor);?>;"><i class="fa fa-whatsapp" aria-hidden="true"></i>					
			<?php	}else if($wc_display_type=='only_text'){ ?>
					<a href="<?php echo esc_url($wcShareUrl); ?>" class="wc_share_icon_display wc_only_text <?php echo 'wc_button_'.esc_attr($wc_animation);?>" tooltip="<?php echo esc_attr($wc_tooltip_share_message);?>" target="_blank" action="share/whatsapp/share" style="background-color:<?php echo esc_attr($wc_bg_sharecolor);?>;color:<?php echo esc_attr($wc_txt_sharecolor);?>;"><?php echo esc_html($wc_button_txt);?>
			<?php	} ?> 
					</a></span> 
					<input type="hidden" id="wc_share_hvr_color" value="<?php echo esc_attr($wc_txthvr_sharecolor); ?>">
					<input type="hidden" id="wc_share_bdr_color" value="<?php echo esc_attr($wc_txt_sharecolor); ?>"> 
			</span>
 
			
		<?php } 
		return ob_get_clean();			
	}

}
